==> ejc-businessplan-impl-3.0.0-20220706.171536-96-sources.jar: com/ejianc/business/busniessplan/vo/PlanprojectVO.java <==
package com.ejianc.business.busniessplan.vo;

import java.util.List;
import java.util.ArrayList;

import com.ejianc.business.record.vo.RecordPlanprojectVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 项目商务策划立项
 * 
 * @author generator
 * 
 */
public class PlanprojectVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.lang.String remarks; // 备注
    private java.lang.Long agentId; // 经办人
    private java.lang.String agentName; // 经办人姓名
    private java.math.BigDecimal costEstimateTotal; // 成本估算(成本分析)汇总金额
    private java.math.BigDecimal reportAmountTotal; // 上报金额汇总
    private java.math.BigDecimal targetAmountTotal; // 策划目标金额汇总
    private java.math.BigDecimal completeAmountTotal; // 已完成目标金额汇总
    private java.math.BigDecimal estimateProfitsTotal; // 预计利润汇总

    private java.lang.String createTimeShow; // 创建时间文本显示
    private java.lang.String billStateStr; // 单据状态文本显示
    private java.lang.String sort; // 序号
    private java.lang.String projectCategory;//项目类别

    private List<PlanprojectdetailVO> planprojectdetailEntities = new ArrayList<>(); // 项目商务策划立项子表
    private List<RecordPlanprojectVO> recordPlanprojectList = new ArrayList<>(); // 历史信息


    public String getProjectCategory() {
        return projectCategory;
    }

    public void setProjectCategory(String projectCategory) {
        this.projectCategory = projectCategory;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 成本估算(成本分析)汇总金额
     */
    public java.math.BigDecimal getCostEstimateTotal() {
        return costEstimateTotal;
    }

    /**
     * 成本估算(成本分析)汇总金额
     */
    public void setCostEstimateTotal(java.math.BigDecimal costEstimateTotal) {
        this.costEstimateTotal = costEstimateTotal;
    }
    /**
     * 上报金额汇总
     */
    public java.math.BigDecimal getReportAmountTotal() {
        return reportAmountTotal;
    }

    /**
     * 上报金额汇总
     */
    public void setReportAmountTotal(java.math.BigDecimal reportAmountTotal) {
        this.reportAmountTotal = reportAmountTotal;
    }
    /**
     * 策划目标金额汇总
     */
    public java.math.BigDecimal getTargetAmountTotal() {
        return targetAmountTotal;
    }

    /**
     * 策划目标金额汇总
     */
    public void setTargetAmountTotal(java.math.BigDecimal targetAmountTotal) {
        this.targetAmountTotal = targetAmountTotal;
    }
    /**
     * 已完成目标金额汇总
     */
    public java.math.BigDecimal getCompleteAmountTotal() {
        return completeAmountTotal;
    }

    /**
     * 已完成目标金额汇总
     */
    public void setCompleteAmountTotal(java.math.BigDecimal completeAmountTotal) {
        this.completeAmountTotal = completeAmountTotal;
    }
    /**
     * 预计利润汇总
     */
    public java.math.BigDecimal getEstimateProfitsTotal() {
        return estimateProfitsTotal;
    }

    /**
     * 预计利润汇总
     */
    public void setEstimateProfitsTotal(java.math.BigDecimal estimateProfitsTotal) {
        this.estimateProfitsTotal = estimateProfitsTotal;
    }

    public List<PlanprojectdetailVO> getPlanprojectdetailEntities() {
        return planprojectdetailEntities;
    }

    public void setPlanprojectdetailEntities(List<PlanprojectdetailVO> planprojectdetailEntities) {
        this.planprojectdetailEntities = planprojectdetailEntities;
    }

    public List<RecordPlanprojectVO> getRecordPlanprojectList() {
        return recordPlanprojectList;
    }

    public void setRecordPlanprojectList(List<RecordPlanprojectVO> recordPlanprojectList) {
        this.recordPlanprojectList = recordPlanprojectList;
    }
}

==> ejc-businessplan-impl-3.0.0-20251209.082428-236-sources.jar: com/ejianc/business/busniessplan/vo/PlanprojectVO.java <==
package com.ejianc.business.busniessplan.vo;

import java.util.List;
import java.util.ArrayList;

import com.ejianc.business.record.vo.RecordPlanprojectVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 项目商务策划立项
 * 
 * @author generator
 * 
 */
public class PlanprojectVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.lang.String remarks; // 备注
    private java.lang.Long agentId; // 经办人
    private java.lang.String agentName; // 经办人姓名
    private java.math.BigDecimal costEstimateTotal; // 成本估算(成本分析)汇总金额
    private java.math.BigDecimal reportAmountTotal; // 上报金额汇总
    private java.math.BigDecimal targetAmountTotal; // 策划目标金额汇总
    private java.math.BigDecimal completeAmountTotal; // 已完成目标金额汇总
    private java.math.BigDecimal estimateProfitsTotal; // 预计利润汇总

    private java.lang.String createTimeShow; // 创建时间文本显示
    private java.lang.String billStateStr; // 单据状态文本显示
    private java.lang.String sort; // 序号
    private java.lang.String projectCategory;//项目类别
    private Integer lineNum;//子表行数

    private List<PlanprojectdetailVO> planprojectdetailEntities = new ArrayList<>(); // 项目商务策划立项子表
    private List<RecordPlanprojectVO> recordPlanprojectList = new ArrayList<>(); // 历史信息

    public Integer getLineNum() {
        return lineNum;
    }

    public void setLineNum(Integer lineNum) {
        this.lineNum = lineNum;
    }

    public String getProjectCategory() {
        return projectCategory;
    }

    public void setProjectCategory(String projectCategory) {
        this.projectCategory = projectCategory;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode="idm-user")
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 成本估算(成本分析)汇总金额
     */
    public java.math.BigDecimal getCostEstimateTotal() {
        return costEstimateTotal;
    }

    /**
     * 成本估算(成本分析)汇总金额
     */
    public void setCostEstimateTotal(java.math.BigDecimal costEstimateTotal) {
        this.costEstimateTotal = costEstimateTotal;
    }
    /**
     * 上报金额汇总
     */
    public java.math.BigDecimal getReportAmountTotal() {
        return reportAmountTotal;
    }

    /**
     * 上报金额汇总
     */
    public void setReportAmountTotal(java.math.BigDecimal reportAmountTotal) {
        this.reportAmountTotal = reportAmountTotal;
    }
    /**
     * 策划目标金额汇总
     */
    public java.math.BigDecimal getTargetAmountTotal() {
        return targetAmountTotal;
    }

    /**
     * 策划目标金额汇总
     */
    public void setTargetAmountTotal(java.math.BigDecimal targetAmountTotal) {
        this.targetAmountTotal = targetAmountTotal;
    }
    /**
     * 已完成目标金额汇总
     */
    public java.math.BigDecimal getCompleteAmountTotal() {
        return completeAmountTotal;
    }

    /**
     * 已完成目标金额汇总
     */
    public void setCompleteAmountTotal(java.math.BigDecimal completeAmountTotal) {
        this.completeAmountTotal = completeAmountTotal;
    }
    /**
     * 预计利润汇总
     */
    public java.math.BigDecimal getEstimateProfitsTotal() {
        return estimateProfitsTotal;
    }

    /**
     * 预计利润汇总
     */
    public void setEstimateProfitsTotal(java.math.BigDecimal estimateProfitsTotal) {
        this.estimateProfitsTotal = estimateProfitsTotal;
    }

    public List<PlanprojectdetailVO> getPlanprojectdetailEntities() {
        return planprojectdetailEntities;
    }

    public void setPlanprojectdetailEntities(List<PlanprojectdetailVO> planprojectdetailEntities) {
        this.planprojectdetailEntities = planprojectdetailEntities;
    }

    public List<RecordPlanprojectVO> getRecordPlanprojectList() {
        return recordPlanprojectList;
    }

    public void setRecordPlanprojectList(List<RecordPlanprojectVO> recordPlanprojectList) {
        this.recordPlanprojectList = recordPlanprojectList;
    }
}
